==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkPlotFunctionalBag.java <==
// java wrapper for vtkPlotFunctionalBag object
//

package vtk;
import vtk.*;

public class vtkPlotFunctionalBag extends vtkPlot
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean IsBag_2();
  public boolean IsBag()
    { return IsBag_2(); }

  private native boolean GetVisible_3();
  public boolean GetVisible()
    { return GetVisible_3(); }

  private native void Update_4();
  public void Update()
    { Update_4(); }

  private native boolean Paint_5(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_5(id0); }

  private native void GetBounds_6(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_6(id0); }

  private native void GetUnscaledInputBounds_7(double id0[]);
  public void GetUnscaledInputBounds(double id0[])
    { GetUnscaledInputBounds_7(id0); }

  private native void SetLookupTable_8(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_8(id0); }

  private native long GetLookupTable_9();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_9();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultLookupTable_10();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_10(); }

  public vtkPlotFunctionalBag() { super(); }

  public vtkPlotFunctionalBag(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkPlotFunctionalBag.java <==
// java wrapper for vtkPlotFunctionalBag object
//

package vtk;
import vtk.*;

public class vtkPlotFunctionalBag extends vtkPlot
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean IsBag_2();
  public boolean IsBag()
    { return IsBag_2(); }

  private native boolean GetVisible_3();
  public boolean GetVisible()
    { return GetVisible_3(); }

  private native void Update_4();
  public void Update()
    { Update_4(); }

  private native boolean Paint_5(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_5(id0); }

  private native void GetBounds_6(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_6(id0); }

  private native void GetUnscaledInputBounds_7(double id0[]);
  public void GetUnscaledInputBounds(double id0[])
    { GetUnscaledInputBounds_7(id0); }

  private native void SetLookupTable_8(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_8(id0); }

  private native long GetLookupTable_9();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_9();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLookupTable_10();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_10(); }

  public vtkPlotFunctionalBag() { super(); }

  public vtkPlotFunctionalBag(long id) { super(id); }
  public native long   VTKInit();

}
